/*
 * Copyright 2017-2020 by Kappich Systemberatung, Aachen
 *
 * This file is part of de.kappich.pat.gnd.
 *
 * de.kappich.pat.gnd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.kappich.pat.gnd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.kappich.pat.gnd.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Pascalstraße 53
 * 52076 Aachen, Germany
 * phone: +49 2408 7047 240
 * mail: <info@kappich.de>
 */

package de.kappich.pat.gnd.properties;

import de.bsvrz.sys.funclib.kappich.annotations.Nullable;
import de.kappich.pat.gnd.utils.SpringUtilities;
import java.awt.Dimension;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.SpringLayout;
import javax.swing.event.ChangeListener;

/**
 * Diese Klasse verkapselt die Eigenschaft Textgröße.
 *
 * @author Kappich Systemberatung
 */
public final class TextSizeProperty extends AbstractProperty {
    private static final TextSizeProperty _instance = new TextSizeProperty();
    private static final String KEY = "textsize";
    private static final Integer DEFAULT_TEXT_SIZE = 12;

    private TextSizeProperty() {
        super("Textgröße");
    }

    public static Property getInstance() {
        return _instance;
    }

    @Override
    public Object getDefaultValue() {
        return DEFAULT_TEXT_SIZE;
    }

    @Override
    public String getKey() {
        return KEY;
    }

    @Override
    public PropertyPanel getPropertyPanel(@Nullable Object value, boolean changeable) {
        if (value != null) {
            return new TextSizePanel((Integer) value, changeable);
        } else {
            return new TextSizePanel(DEFAULT_TEXT_SIZE, changeable);
        }
    }

    private static class TextSizePanel extends JPanel implements PropertyPanel {
        private final JSpinner _textSizeSpinner = new JSpinner(new SpinnerNumberModel(12, 4, 100, 1));

        // die alten Werte waren: 20, 0, 10000, 1
        public TextSizePanel(Integer distance, boolean changeable) {
            JLabel label = new JLabel("Schriftgröße: ");
            _textSizeSpinner.setMaximumSize(new Dimension(200, 20));
            _textSizeSpinner.setValue(distance);
            _textSizeSpinner.setEnabled(changeable);
            setLayout(new SpringLayout());
            add(label);
            add(_textSizeSpinner);
            SpringUtilities.makeCompactGrid(this, 2, 5, 5);
        }

        @Override
        public void addListener(final PropertyPanelListener listener) {
            ChangeListener changeListener = e -> listener.stateChanged();
            _textSizeSpinner.addChangeListener(changeListener);
        }

        @Override
        public Object getPropertyValue() {
            return _textSizeSpinner.getValue();
        }

        @Override
        public void setSelectionEnabled(final boolean enabled) {
            _textSizeSpinner.setEnabled(enabled);
        }
    }
}
